@@ -73,7 +73,7 @@ async def get_item(client: TonlibClient, addr: str, nft_items: list, items: dict
 
     s = time.time()
     if items:
-        if str(x['index']) in items:
+        if str(x['index']) in items or Address(addr).to_string(is_user_friendly=False) in items:
             content = items[str(x['index'])]
             # print(time.time() - s)
         else:
